@@ -1,8 +1,9 @@
 """Support for a Netatmo account."""
+
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, cast
 from uuid import uuid4
 
 from pyatmo import modules
@@ -17,9 +18,9 @@ from pyatmo.const import (
     SETSTATE_ENDPOINT,
     RawData,
 )
-from pyatmo.helpers import extract_raw_data_new
+from pyatmo.helpers import extract_raw_data
 from pyatmo.home import Home
-from pyatmo.modules.module import MeasureInterval, Module
+from pyatmo.modules.module import Energy, MeasureInterval, Module
 
 if TYPE_CHECKING:
     from pyatmo.auth import AbstractAsyncAuth
@@ -30,14 +31,16 @@ LOG = logging.getLogger(__name__)
 class AsyncAccount:
     """Async class of a Netatmo account."""
 
-    def __init__(self, auth: AbstractAsyncAuth, favorite_stations: bool = True) -> None:
-        """Initialize the Netatmo account.
+    def __init__(
+        self,
+        auth: AbstractAsyncAuth,
+        favorite_stations: bool = True,
+    ) -> None:
+        """Initialize the Netatmo account."""
 
-        Arguments:
-            auth {AbstractAsyncAuth} -- Authentication information with valid access token
-        """
         self.auth: AbstractAsyncAuth = auth
         self.user: str | None = None
+        self.all_homes_id: dict[str, str] = {}
         self.homes: dict[str, Home] = {}
         self.raw_data: RawData = {}
         self.favorite_stations: bool = favorite_stations
@@ -45,28 +48,47 @@ class AsyncAccount:
         self.modules: dict[str, Module] = {}
 
     def __repr__(self) -> str:
+        """Return the representation."""
+
         return (
             f"{self.__class__.__name__}(user={self.user}, home_ids={self.homes.keys()}"
         )
 
-    def process_topology(self) -> None:
+    def process_topology(self, disabled_homes_ids: list[str] | None = None) -> None:
         """Process topology information from /homesdata."""
+
+        if disabled_homes_ids is None:
+            disabled_homes_ids = []
+
         for home in self.raw_data["homes"]:
-            if (home_id := home["id"]) in self.homes:
+            home_id = home.get("id", "Unknown")
+            home_name = home.get("name", "Unknown")
+            self.all_homes_id[home_id] = home_name
+
+            if home_id in disabled_homes_ids:
+                if home_id in self.homes:
+                    del self.homes[home_id]
+                continue
+
+            if home_id in self.homes:
                 self.homes[home_id].update_topology(home)
             else:
                 self.homes[home_id] = Home(self.auth, raw_data=home)
 
-    async def async_update_topology(self) -> None:
+    async def async_update_topology(
+        self,
+        disabled_homes_ids: list[str] | None = None,
+    ) -> None:
         """Retrieve topology data from /homesdata."""
+
         resp = await self.auth.async_post_api_request(
             endpoint=GETHOMESDATA_ENDPOINT,
         )
-        self.raw_data = extract_raw_data_new(await resp.json(), "homes")
+        self.raw_data = extract_raw_data(await resp.json(), "homes")
 
         self.user = self.raw_data.get("user", {}).get("email")
 
-        self.process_topology()
+        self.process_topology(disabled_homes_ids=disabled_homes_ids)
 
     async def async_update_status(self, home_id: str) -> None:
         """Retrieve status data from /homestatus."""
@@ -74,8 +96,8 @@ class AsyncAccount:
             endpoint=GETHOMESTATUS_ENDPOINT,
             params={"home_id": home_id},
         )
-        raw_data = extract_raw_data_new(await resp.json(), HOME)
-        await self.homes[home_id].update(raw_data)
+        raw_data = extract_raw_data(await resp.json(), HOME)
+        await self.homes[home_id].update(raw_data, do_raise_for_reachability_error=True)
 
     async def async_update_events(self, home_id: str) -> None:
         """Retrieve events from /getevents."""
@@ -83,7 +105,7 @@ class AsyncAccount:
             endpoint=GETEVENTS_ENDPOINT,
             params={"home_id": home_id},
         )
-        raw_data = extract_raw_data_new(await resp.json(), HOME)
+        raw_data = extract_raw_data(await resp.json(), HOME)
         await self.homes[home_id].update(raw_data)
 
     async def async_update_weather_stations(self) -> None:
@@ -103,14 +125,21 @@ class AsyncAccount:
         home_id: str,
         module_id: str,
         start_time: int | None = None,
+        end_time: int | None = None,
         interval: MeasureInterval = MeasureInterval.HOUR,
         days: int = 7,
     ) -> None:
-        await getattr(self.homes[home_id].modules[module_id], "async_update_measures")(
-            start_time=start_time,
-            interval=interval,
-            days=days,
-        )
+        """Retrieve measures data from /getmeasure."""
+
+        module = self.homes[home_id].modules[module_id]
+        if module.has_feature("historical_data"):
+            module = cast("Energy", module)
+            await module.async_update_measures(
+                start_time=start_time,
+                end_time=end_time,
+                interval=interval,
+                days=days,
+            )
 
     def register_public_weather_area(
         self,
@@ -124,6 +153,7 @@ class AsyncAccount:
         area_id: str = str(uuid4()),
     ) -> str:
         """Register public weather area to monitor."""
+
         self.public_weather_areas[area_id] = modules.PublicWeatherArea(
             lat_ne,
             lon_ne,
@@ -135,7 +165,7 @@ class AsyncAccount:
         return area_id
 
     async def async_update_public_weather(self, area_id: str) -> None:
-        """Retrieve status data from /getpublicdata"""
+        """Retrieve status data from /getpublicdata."""
         params = {
             "lat_ne": self.public_weather_areas[area_id].location.lat_ne,
             "lon_ne": self.public_weather_areas[area_id].location.lon_ne,
@@ -161,7 +191,7 @@ class AsyncAccount:
     ) -> None:
         """Retrieve status data from <endpoint>."""
         resp = await self.auth.async_post_api_request(endpoint=endpoint, params=params)
-        raw_data = extract_raw_data_new(await resp.json(), tag)
+        raw_data = extract_raw_data(await resp.json(), tag)
         await self.update_devices(raw_data, area_id)
 
     async def async_set_state(self, home_id: str, data: dict[str, Any]) -> None:
@@ -214,7 +244,7 @@ class AsyncAccount:
                     {HOME: {"modules": [normalize_weather_attributes(device_data)]}},
                 )
             else:
-                LOG.debug("No home %s found.", home_id)
+                LOG.debug("No home %s (%s) found.", home_id, home_id)
 
             for module_data in device_data.get("modules", []):
                 module_data["home_id"] = home_id
